# add-links to your pyproject

- <https://packaging.python.org/en/latest/guides/writing-pyproject-toml/#writing-pyproject-toml-urls>
- <https://packaging.python.org/en/latest/specifications/well-known-project-urls/#well-known-labels>
